@@ -2,11 +2,11 @@
 package cdklabscdkcodepipelineextensions
 
 
+// Options for creating a calendar object.
 // Experimental.
 type CalendarLocationOptionsBase struct {
+	// The name of the calendar file.
 	// Experimental.
 	CalendarName *string `field:"required" json:"calendarName" yaml:"calendarName"`
-	// Experimental.
-	CalendarPath *string `field:"optional" json:"calendarPath" yaml:"calendarPath"`
 }
 
